@@ -14,7 +14,7 @@
 #include <sy/sygpio_server.h>
 #include <sy/syrouting.h>
 
-#define SYGPIOTEST_USAGE "\n"
+#define SYGPIOTEST_USAGE "--log\n"
 
 class MainObject : public QObject
 {
@@ -23,12 +23,12 @@ class MainObject : public QObject
   MainObject(QObject *parent=0);
 
  private slots:
-  void gpiReceivedData(int gpi,int line,bool state,bool pulse);
-  void gpoReceivedData(int gpo,int line,bool state,bool pulse);
+  void gpioReceivedData(SyGpioEvent *e);
 
  private:
   SyRouting *gpio_routing;
   SyGpioServer *gpio_server;
+  bool gpio_log;
 };
 
 
